@@ -4,7 +4,7 @@
  *
  * client specific stuff
  *
- * $Id: client.c,v 1.11 2004/11/21 23:53:30 jon Exp $
+ * $Id: client.c,v 1.14 2005/11/05 21:40:44 jon Exp $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -18,6 +18,7 @@
 #include "client.h"
 #undef CLIENT_NOEXTERN
 
+#include "conqlb.h"
 #include "clientlb.h"
 #include "conqcom.h"
 #include "context.h"
@@ -382,8 +383,9 @@ int procPlanetInfo(Unsgn8 *buf)
     return FALSE;
 
   primary = splaninfo->primary;
-  
-  if (primary <= 0 || primary > NUMPLANETS)
+
+  /* Roy fix - 10/17/2005 - let's mur data be sent. */
+  if (primary < 0 || primary > NUMPLANETS)
     return FALSE;
 
   /* we will record them if we get them */
@@ -683,10 +685,19 @@ int sendCommand(Unsgn8 cmd, Unsgn16 detail)
   ccmd.cmd = cmd;
   ccmd.detail = htons(detail);
 
-  if (writePacket(PKT_TOSERVER, cInfo.sock, (Unsgn8 *)&ccmd) <= 0)
-    return FALSE;
-  else 
-    return TRUE;
+  if (cmd == CPCMD_KEEPALIVE && cInfo.usock != -1)
+    {
+      writePacket(PKT_TOSERVER, cInfo.usock, (Unsgn8 *)&ccmd);
+      return TRUE;
+    }
+  else
+    {
+
+      if (writePacket(PKT_TOSERVER, cInfo.sock, (Unsgn8 *)&ccmd) <= 0)
+        return FALSE;
+      else 
+        return TRUE;
+    }
 }
 
 int sendFireTorps(int num, real dir)
@@ -961,6 +972,7 @@ void processPacket(Unsgn8 *buf)
     case SP_TEAM:
       procTeam(buf);
       break;
+
     case SP_CLIENTSTAT:
       scstat = (spClientStat_t *)buf;
       Context.snum = scstat->snum;
@@ -1012,4 +1024,24 @@ void processPacket(Unsgn8 *buf)
   return;
 }
 
+/* Some routers/firewalls seem to disconnect a UDP conncetion if there haven't
+ * been any outgoing (client->server) packets for awhile.  Normally, conquest
+ * never sends UDP packets except during UDP negotiation at the start of a
+ * game.  This routine will send a CPCMD_KEEPALIVE packet every 60 seconds
+ * if a UDP connection is enabled.  Seems to solve clute's problem.
+ */
+void sendUDPKeepAlive(void)
+{
+  static Unsgn32 katime = 0;     /* UDP keepalive packets */
+  const Unsgn32 kawait = 60000;  /* ms (60 seconds) */
+  Unsgn32 iternow = clbGetMillis();  
 
+  /* send a UDP keepalive packet if it's time */
+  if (((iternow - katime) > kawait) && cInfo.usock != -1)
+    {
+      sendCommand(CPCMD_KEEPALIVE, 0);
+      katime = iternow;
+    }
+
+  return;
+}
