@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conqlb.c,v 1.24 2004/12/26 08:19:31 jon Exp $
+ * $Id: conqlb.c,v 1.26 2005/08/10 15:51:38 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -838,22 +838,14 @@ int clbTakePlanet( int pnum, int snum )
           Users[Ships[snum].unum].stats[USTAT_GENOCIDE] += 1;
           Teams[Ships[snum].team].stats[TSTAT_GENOCIDE] += 1;
 
-#if 0
-          for (i=1; i <= MAXSHIPS; i++)
-            {                   /* eliminate any geno'd armies from ships */
-              if (Ships[i].status == SS_LIVE && Ships[i].team == oteam &&
-                  Ships[i].armies > 0)
-                {
-                  clog("INFO: summarily suicided %d geno'd armies on ship %d",
-                       Ships[i].armies, i);
-                  Ships[i].armies = 0;
-                }
-            }
-#endif
-	  clog("INFO: %s (%s) genocided the %s team!",
-	       Users[Ships[snum].unum].username,
-	       Ships[snum].alias,
-	       Teams[oteam].name);
+          sprintf(buf, "%c%d (%s) genocided the %s team!",
+                  Teams[Ships[snum].team].teamchar,
+                  snum,
+                  Ships[snum].alias,
+                  Teams[oteam].name);
+                  
+          clbStoreMsg(MSG_COMP, MSG_ALL, buf);
+          clog(buf);
         }
 
     }
@@ -1077,7 +1069,8 @@ void clbStatline( int unum, char *buf )
 int clbZeroPlanet( int pnum, int snum )
 {
   int oteam, i; 
-  int didgeno;
+  int didgeno = FALSE;
+  char buf[MSGMAXLINE];
 
   oteam = Planets[pnum].team;
   Planets[pnum].team = TEAM_NOTEAM;
@@ -1115,23 +1108,14 @@ int clbZeroPlanet( int pnum, int snum )
               Users[Ships[snum].unum].stats[USTAT_GENOCIDE] += 1;
               Teams[Ships[snum].team].stats[TSTAT_GENOCIDE] += 1;
 
-#if 0
-              for (i=1; i <= MAXSHIPS; i++)
-                { /* eliminate any geno'd armies from ships */
-                  if (Ships[i].status == SS_LIVE && Ships[i].team == oteam &&
-                      Ships[i].armies > 0)
-                    {
-                      clog("INFO: summarily suicided %d geno'd armies on ship %d",
-                           Ships[i].armies, i);
-                      Ships[i].armies = 0;
-                    }
-                }
-#endif
-
-              clog("INFO: %s (%s) genocided the %s team!",
-                   Users[Ships[snum].unum].username,
-                   Ships[snum].alias,
-                   Teams[oteam].name);
+              sprintf(buf, "%c%d (%s) genocided the %s team!",
+                      Teams[Ships[snum].team].teamchar,
+                      snum,
+                      Ships[snum].alias,
+                      Teams[oteam].name);
+              
+              clbStoreMsg(MSG_COMP, MSG_ALL, buf);
+              clog(buf);
             }
         }
     }
