@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conquest.c,v 1.40 2004/12/26 08:19:31 jon Exp $
+ * $Id: conquest.c,v 1.42 2005/12/28 06:13:28 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -3283,14 +3283,16 @@ int play()
       if (recordInitOutput(Context.unum, getnow(NULL, 0), Context.snum))
         {
           Context.recmode = RECMODE_ON;
-          /* need to tell the server to resend all the crap it already
-             sent in menu so it can be recorded... sorry. */
-          sendCommand(CPCMD_RELOAD, 0);
         }
       else
         Context.recmode = RECMODE_OFF;
     }
 
+  /* need to tell the server to resend all the crap it already
+     sent in menu - our ship may have changed */
+  sendCommand(CPCMD_RELOAD, 0);
+  
+
   /* While we're alive, field commands and process them. Inbound
      packets are handled by astservice() */
   /* when we become 'killed', then dead processing can begin. */
@@ -3360,6 +3362,9 @@ int play()
 	  cdrefresh();
         }
 
+      /* send a UDP keepalive packet if it's time */
+      sendUDPKeepAlive();
+
     } /* while stillalive */
 	  
   Context.display = FALSE;
