@@ -4,7 +4,7 @@
  *
  * conquestd - the Conquest server/client driver
  *
- * $Id: conquestd.c,v 1.25 2004/12/26 08:19:31 jon Exp $
+ * $Id: conquestd.c,v 1.27 2005/12/25 20:24:00 jon Exp $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -499,8 +499,6 @@ void updateProc(void)
 
   stopUpdate();
 
-  drcheck();			/* check the driver */  
-
   /* update client view of the universe */
   updateClient(FALSE);
 
@@ -1115,6 +1113,9 @@ void handleSimpleCmdPkt(cpCommand_t *ccmd)
       clbUnblockAlarm();
       break;
 
+    case CPCMD_KEEPALIVE:       /* these we just ignore */
+      break;
+
     default:
       clog("conquestd: handleSimpleCmdPkt(): unexpected command code %d",
 	   cmd);
@@ -1632,6 +1633,11 @@ int play(void)
 	  laststat = now;
 	}
 
+      clbBlockAlarm();          /* no signals can be accepted when
+                                   drcheck is run */
+      drcheck();
+      clbUnblockAlarm();
+
       if (didsomething)         
         continue;               /* see if there is another pkt */
 
