@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: gldisplay.c,v 1.10 2004/12/26 08:19:31 jon Exp $
+ * $Id: gldisplay.c,v 1.12 2005/07/11 06:09:35 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -48,7 +48,7 @@ extern real LastPhasDist;	/* defined in conqlb.c */
 
 static int alertcolor(int alert)
 {
-  int theattrib;
+  int theattrib = 0;
   
   switch (alert)
     {
@@ -77,7 +77,7 @@ static int alertcolor(int alert)
 void display( int snum, int display_info )
 {
   int i, j, minenemy, minsenemy;
-  int outattr;
+  int outattr = 0;
   static int OldAlert = 0;
   char ch, buf[MSGMAXLINE];
   int dobeep, lsmap;
@@ -110,6 +110,8 @@ void display( int snum, int display_info )
   minenemy = 0;
   minsenemy = 0;
 
+  dis = 0;
+
   if (snum > 0)
     lsmap = SMAP(snum);
   else
@@ -234,7 +236,7 @@ void display( int snum, int display_info )
 					 &glx, &gly ) )
 			  {
 			    drawTorp(glx, gly, Teams[Ships[i].team].torpchar, 
-				     color, scale);			    
+				     color, scale, i, j);			    
 			  }
 		  }
 	      }
@@ -348,7 +350,7 @@ void display( int snum, int display_info )
 		if ( GLcvtcoords( cenx, ceny, Ships[i].torps[j].x, 
                                   Ships[i].torps[j].y, scale, &glx, &gly ))
 		  { 
-		    drawExplosion(glx, gly);
+		    drawExplosion(glx, gly, i, j);
 		  }
 	  /* Now display the live torps. */
 	  
@@ -374,7 +376,7 @@ void display( int snum, int display_info )
                                Ships[i].torps[j].y, scale, &glx, &gly))
 		{
 		  drawTorp(glx, gly, Teams[Ships[i].team].torpchar, color,
-                           scale);
+                           scale, i, j);
 		}
 	}
     }
