@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: ibuf.h,v 1.5 2003/11/02 20:53:00 jon Exp $
+ * $Id: ibuf.h,v 1.6 2004/05/08 21:01:41 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -23,6 +23,6 @@ int iBufCount(void);
 void iBufPut(char *thestr);
 void iBufPutc(unsigned int thechar);
 unsigned int iBufGetCh(void);
-int DoMacro(int ch);
+int DoMacro(int fkey);
 
 #endif
