@@ -1,7 +1,7 @@
 /* 
  * cockpit node
  *
- * $Id: nCP.c,v 1.21 2004/12/28 01:35:26 jon Exp $
+ * $Id: nCP.c,v 1.24 2005/12/25 20:24:00 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -40,6 +40,7 @@
 
 #include "nCP.h"
 
+/* node specific states */
 #define S_NONE         0
 #define S_COURSE       1        /* setting course */
 #define S_DOINFO       2
@@ -2465,7 +2466,7 @@ static int nCPIdle(void)
   static Unsgn32 iterstart = 0;
   static Unsgn32 pingtime = 0;
   Unsgn32 iternow = clbGetMillis();
-  const Unsgn32 iterwait = 50; /* ms */
+  const Unsgn32 iterwait = 50;   /* ms */
   const Unsgn32 pingwait = 2000; /* ms (2 seconds) */
   real tdelta = (real)iternow - (real)iterstart;
 
@@ -2508,6 +2509,9 @@ static int nCPIdle(void)
       return NODE_EXIT;
     }
 
+  /* send a UDP keepalive packet if it's time */
+  sendUDPKeepAlive();
+
   /* send a ping if it's time */
   if (!pingPending && ((iternow - pingtime) > pingwait))
     {                           /* send a ping request */
